Package: consensus
Title: Cross-platform consensus analysis of genomic measurements via
        interlaboratory testing method
Version: 1.28.0
Date: 2020-05-22
Author: Tim Peters
Maintainer: Tim Peters <t.peters@garvan.org.au>
Authors@R: c(person("Tim", "Peters", role = c("cre", "aut"),
                    email = "t.peters@garvan.org.au"),
	     person("Benedetta Frida", "Baldi", role = "art",
		    email = "b.baldi@garvan.org.au"))
Description: An implementation of the American Society for Testing and Materials (ASTM) Standard E691 for interlaboratory testing procedures, designed for cross-platform genomic measurements. Given three (3) or more genomic platforms or laboratory protocols, this package provides interlaboratory testing procedures giving per-locus comparisons for sensitivity and precision between platforms.   
Depends: R (>= 3.5), RColorBrewer
Imports: matrixStats, gplots, grDevices, methods, graphics, stats,
        utils
biocViews: QualityControl, Regression, DataRepresentation,
        GeneExpression, Microarray, RNASeq
Suggests: knitr, RUnit, rmarkdown, BiocGenerics
License: BSD_3_clause + file LICENSE
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/consensus
git_branch: RELEASE_3_22
git_last_commit: 41b16d0
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 03:16:20 UTC; biocbuild
