\name{consensus-internal}
\title{
Internal consensus objects and functions
}
\alias{checkMM}
\alias{fitMandel}
\alias{getBlock}
\description{
Internal consensus objects and functions
}
\keyword{internal}

